@@ -18,7 +18,11 @@
 #include "ui_mainwindow.h"
 
 #ifndef CV_WINDOW_NORMAL
-    #define CV_WINDOW_NORMAL 0x00000000
+    #define CV_WINDOW_NORMAL   0x00000000 //the user can resize the window (no constraint)  / also use to switch a fullscreen window to a normal size
+#endif
+
+#ifndef CV_WINDOW_AUTOSIZE
+    #define CV_WINDOW_AUTOSIZE 0x00000001 //the user cannot resize the window, the size is constrainted by the image displayed
 #endif
 
 #ifndef cvCopyImage
@@ -38,7 +42,7 @@ MainWindow::MainWindow(QWidget *parent) :
     char *PROGRAM_DIR=get_absolute_speckle_tool_path();
     //qWarning()<<PROGRAM_DIR<<endl;
     setWindowIcon(QIcon(QString(PROGRAM_DIR)+"../share/speckletool/icons/camera.png"));
-    setWindowTitle("Speckle Tool"+QString(APP_VERSION));
+    setWindowTitle("Speckle Tool "+QString(APP_VERSION));
 
     algorhitm_selected_execute = CAMERA;
     selected_image_camera = NORMAL_CAMERA;
@@ -47,6 +51,10 @@ MainWindow::MainWindow(QWidget *parent) :
     saveMode = false;
     firstTime = true;
     mhiObj=NULL;
+    lastT=0.0;
+    lastT0=0.0;
+    sisObj=NULL;
+    fd_time=NULL;
 
     ui->action_Open                 ->setIcon(QIcon(QString(PROGRAM_DIR)+"../share/speckletool/icons/document-open.png"));
     ui->action_Salve_Video          ->setIcon(QIcon(QString(PROGRAM_DIR)+"../share/speckletool/icons/document-save.png"));
@@ -121,19 +129,19 @@ void MainWindow::on_cam_pushButton_clicked()
             switch(algorhitm_selected_execute)
             {
                 case LASCA:
-                    cvNamedWindow("LASCA", 1);
+                    cvNamedWindow("LASCA", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("LASCA", 435, 0);
                     break;
                 case MHI:
-                    cvNamedWindow("MHI", 1);
+                    cvNamedWindow("MHI", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("MHI", 435, 0);
                     break;
                 case REGIOES:
-                    cvNamedWindow("Regions", 1);
+                    cvNamedWindow("Regions", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("Regions", 435, 0);
                     break;
                 case CAMERA:
-                    cvNamedWindow("Camera", 1);
+                    cvNamedWindow("Camera", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("Camera", 435, 0);
                     break;
             }
@@ -186,19 +194,19 @@ void MainWindow::on_processing_checkBox_stateChanged(int value)
         switch(algorhitm_selected_execute)
         {
             case LASCA:
-                cvNamedWindow("LASCA", 1);
+                cvNamedWindow("LASCA", CV_WINDOW_AUTOSIZE);
                 cvMoveWindow("LASCA", 435, 0);
                 break;
             case MHI:
-                cvNamedWindow("MHI", 1);
+                cvNamedWindow("MHI", CV_WINDOW_AUTOSIZE);
                 cvMoveWindow("MHI", 435, 0);
                 break;
             case REGIOES:
-                cvNamedWindow("Regions", 1);
+                cvNamedWindow("Regions", CV_WINDOW_AUTOSIZE);
                 cvMoveWindow("Regions", 435, 0);
                 break;
             case CAMERA:
-                cvNamedWindow("Camera", 1);
+                cvNamedWindow("Camera", CV_WINDOW_AUTOSIZE);
                 cvMoveWindow("Camera", 435, 0);
                 break;
         }
@@ -238,7 +246,7 @@ void MainWindow::on_lasca_execute_radioButton_clicked()
             cvDestroyWindow("Camera");
             break;
         }
-        cvNamedWindow("LASCA", 1);
+        cvNamedWindow("LASCA", CV_WINDOW_AUTOSIZE);
         cvMoveWindow("LASCA", 435, 0);
         ui->tabWidget->setCurrentIndex(4);
     }
@@ -261,7 +269,7 @@ void MainWindow::on_mhi_execute_radioButton_clicked()
             cvDestroyWindow("Camera");
             break;
         }
-        cvNamedWindow("MHI", 1);
+        cvNamedWindow("MHI", CV_WINDOW_AUTOSIZE);
         cvMoveWindow("MHI", 435, 0);
         ui->tabWidget->setCurrentIndex(3);
     }
@@ -284,7 +292,7 @@ void MainWindow::on_regions_execute_radioButton_clicked()
             cvDestroyWindow("Camera");
             break;
         }
-        cvNamedWindow("Regions", 1);
+        cvNamedWindow("Regions", CV_WINDOW_AUTOSIZE);
         cvMoveWindow("Regions", 435, 0);
         ui->tabWidget->setCurrentIndex(2);
     }
@@ -307,7 +315,7 @@ void MainWindow::on_camera_execute_radioButton_clicked()
             cvDestroyWindow("Regions");
             break;
         }
-        cvNamedWindow("Camera", 1);
+        cvNamedWindow("Camera", CV_WINDOW_AUTOSIZE);
         cvMoveWindow("Camera", 435, 0);
         ui->tabWidget->setCurrentIndex(1);
     }
@@ -392,8 +400,10 @@ void MainWindow::camera_second()
 void MainWindow::start_processing()
 {
     // Create camera Object.
+    cvReleaseCapture(&camera);
     camera = cvCreateCameraCapture(selected_camera);
-    assert(camera);
+    assert(camera);//assert will terminate the program if its argument turns out to be false
+
     mhiObj = new Mhi(ui->nFrames_spinBox->value());
     // Star Timer Event.
     timer = startTimer(1000/ui->fps_spinBox->value());
@@ -410,10 +420,12 @@ void MainWindow::stop_processing()
     delete mhiObj;mhiObj=NULL;
     killTimer(timer);
     cvReleaseCapture(&camera);
+    camera=NULL;
 }
 
 void MainWindow::timerEvent(QTimerEvent *)
 {
+    double currentT;
 
     switch(mode)
     {
@@ -435,6 +447,7 @@ void MainWindow::timerEvent(QTimerEvent *)
                 killTimer(timer_SaveVideoMode);
                 cvReleaseVideoWriter(&writer);
                 cvReleaseCapture(&camera);
+                camera=NULL;
             }            
             break;
         }
@@ -442,6 +455,34 @@ void MainWindow::timerEvent(QTimerEvent *)
         {
             if ( count_saveImg < (numImages_SaveMode))
             {
+                if(count_saveImg==0)    
+                {
+                    filename_time = dirName_SaveMode;
+                    filename_time = filename_time.append("/speckletool.time");
+                    fd_time=fopen(filename_time.toStdString().c_str(),"w");
+                    if(fd_time==NULL)   qWarning()<<"Error creating a 'speckletool.time' file. Possible access error."<<endl
+                                                  <<"Are you using the snap version of speckletool program?"<<endl 
+                                                  <<"Snaps only can write in the user home directory and subs."<<endl;
+
+                    lastT   = (double)cvGetTickCount();
+                    lastT0  = lastT;
+                    currentT= lastT;
+
+                }
+                else
+                {
+                    currentT= (double)cvGetTickCount();
+                }
+
+                double deltaTsec   = ( currentT - lastT)/(cvGetTickFrequency()*1000.0);
+                double currentTsec = ( currentT - lastT0)/(cvGetTickFrequency()*1000.0);
+                lastT= currentT;
+
+                if(fd_time!=NULL)
+                    fprintf(fd_time,"%d\t%f\t%f\n",count_saveImg,currentTsec,deltaTsec);
+                if (count_saveImg==(numImages_SaveMode-1))  
+                    {fclose(fd_time);fd_time=NULL;}
+
                 imgCam = cvQueryFrame(camera);
                 imgCamGray = cvCreateImage(cvGetSize(imgCam), 8, 1);
                 cvCvtColor(imgCam, imgCamGray, CV_RGB2GRAY);
@@ -463,15 +504,18 @@ void MainWindow::timerEvent(QTimerEvent *)
                  }
                 count_saveImg++;
 
+
+
                 cvReleaseImage(&imgCamGray);
 
             } else
             {
                 killTimer(timer_SaveImgMode);
                 cvReleaseCapture(&camera);
+                camera=NULL;
+                saveMode=false;
                 count_saveImg = 0;
-                ui->statusBar->showMessage(
-                        QString::fromUtf8("Images Saved successfully!"),5000);
+                ui->statusBar->showMessage( QString::fromUtf8("Images Saved successfully!"),5000);
             }
 
             break;
@@ -481,10 +525,11 @@ void MainWindow::timerEvent(QTimerEvent *)
             double tempo = (double)cvGetTickCount();
 
             // Check to create the camera image.
-            if(ui->histogram_checkBox->isChecked() ||
-               ui->processing_checkBox->isChecked())
+            if( ui->histogram_checkBox->isChecked() || ui->processing_checkBox->isChecked() )
                 imgCam = cvQueryFrame(camera);
 
+
+
             if(!imgCam)
             {
                 if (ui->action_Opened_Video_Mode_Repeat->isChecked() && openedVideoMode)
@@ -524,7 +569,7 @@ void MainWindow::timerEvent(QTimerEvent *)
                 imgCamGray = cvCreateImage(cvGetSize(imgCam), 8, 1);
                 cvCvtColor(imgCam, imgCamGray, CV_RGB2GRAY);
 
-                // Check to create and exhibit the image histogram.
+                 // Check to create and exhibit the image histogram.
                 if(ui->histogram_checkBox->isChecked())
                 {
                     IplImage *imgHist = auxImagemObj->histogram(imgCamGray);
@@ -553,8 +598,7 @@ void MainWindow::timerEvent(QTimerEvent *)
 
                     if(firstTime)
                     {
-                        ui->tabWidget->setCurrentIndex(4 -
-                                                       algorhitm_selected_execute);
+                        ui->tabWidget->setCurrentIndex(4 - algorhitm_selected_execute);
                         firstTime = false;
                     }
 
@@ -591,7 +635,7 @@ void MainWindow::execute_lasca(IplImage *image)
 
         if(saveMode)
         {
-            QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+            QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
             QString name = dirName_SaveMode;
             name = name.append(aux);
             cvSaveImage(name.toLocal8Bit().data(), imgColorLasca);
@@ -612,7 +656,7 @@ void MainWindow::execute_lasca(IplImage *image)
 
         if(saveMode)
         {
-            QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+            QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
 
             QString name = dirName_SaveMode;
             name = name.append(aux);
@@ -638,7 +682,7 @@ void MainWindow::execute_mhi(IplImage *image)
     {
         if(saveMode)
         {
-            QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+            QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
             QString name = dirName_SaveMode;
             name = name.append(aux);
             cvSaveImage(name.toLocal8Bit().data(), mhi_color);
@@ -650,7 +694,7 @@ void MainWindow::execute_mhi(IplImage *image)
     {
         if(saveMode)
         {
-            QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+            QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
             QString name = dirName_SaveMode;
             name = name.append(aux);
             cvSaveImage(name.toLocal8Bit().data(), mhi_gray);
@@ -711,7 +755,7 @@ void MainWindow::execute_regions(IplImage *colorImage, IplImage *grayImage)
 
     if(saveMode)
     {
-        QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+        QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
         QString name = dirName_SaveMode;
         name = name.append(aux);
         cvSaveImage(name.toLocal8Bit().data(), aux1);
@@ -731,7 +775,7 @@ void MainWindow::execute_camera(IplImage *colorImage, IplImage *grayImage)
         case NORMAL_CAMERA:
             if(saveMode)
             {
-                QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+                QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
                 QString name = dirName_SaveMode;
                 name = name.append(aux);
                 cvSaveImage(name.toLocal8Bit().data(), colorImage);
@@ -742,7 +786,7 @@ void MainWindow::execute_camera(IplImage *colorImage, IplImage *grayImage)
         case GRAY_CAMERA:
             if(saveMode)
             {
-                QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+                QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
                 QString name = dirName_SaveMode;
                 name = name.append(aux);
                 cvSaveImage(name.toLocal8Bit().data(), grayImage);
@@ -754,7 +798,7 @@ void MainWindow::execute_camera(IplImage *colorImage, IplImage *grayImage)
             IplImage* imgColor = auxImagemObj->coloreImagem(grayImage);
             if(saveMode)
             {
-                QString aux = "";   aux.sprintf("/%03d.bmp",count_saveImg);
+                QString aux = "";   aux.sprintf("/%d.bmp",count_saveImg);
                 QString name = dirName_SaveMode;
                 name = name.append(aux);
                 cvSaveImage(name.toLocal8Bit().data(), imgColor);
@@ -803,19 +847,19 @@ void MainWindow::execute_openFile()
             switch(algorhitm_selected_execute)
             {
                 case LASCA:
-                    cvNamedWindow("LASCA", 1);
+                    cvNamedWindow("LASCA", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("LASCA", 435, 0);
                     break;
                 case MHI:
-                    cvNamedWindow("MHI", 1);
+                    cvNamedWindow("MHI", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("MHI", 435, 0);
                     break;
                 case REGIOES:
-                    cvNamedWindow("Regions", 1);
+                    cvNamedWindow("Regions", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("Regions", 435, 0);
                     break;
                 case CAMERA:
-                    cvNamedWindow("Camera", 1);
+                    cvNamedWindow("Camera", CV_WINDOW_AUTOSIZE);
                     cvMoveWindow("Camera", 435, 0);
                     break;
             }
@@ -834,7 +878,9 @@ void MainWindow::execute_saveVideo()
         if(camOn)
             on_cam_pushButton_clicked();
 
+        cvReleaseCapture(&camera);
         camera = cvCreateCameraCapture(selected_camera);
+        assert(camera);//assert will terminate the program if its argument turns out to be false
 
         int fps = svObj->getFPS();
         QString file = svObj->getFileName();
@@ -866,9 +912,13 @@ void MainWindow::execute_saveImageSequence()
             on_cam_pushButton_clicked();
 
         saveMode = true;
-        dirName_SaveMode = sisObj->getLocation();
+        dirName_SaveMode   = sisObj->getLocation();
         numImages_SaveMode = sisObj->getNumImage();
+
+        cvReleaseCapture(&camera);
         camera = cvCreateCameraCapture(selected_camera);
+        assert(camera);//assert will terminate the program if its argument turns out to be false
+
         mode = SAVE_IMAGE_MODE;
         count_saveImg = 0;
         timer_SaveImgMode = startTimer(1000/ui->fps_spinBox->value());
