@@ -3,26 +3,29 @@
 
 #include <QFileDialog>
 #include <QDir>
+#include "extras.h"
 
 SaveImageSequenceInterface::SaveImageSequenceInterface(QWidget *parent) :
-    QDialog(parent),
-    ui(new Ui::SaveImageSequenceInterface)
+    QDialog(parent), ui(new Ui::SaveImageSequenceInterface)
 {
+    //The default save as path is the current path
     ui->setupUi(this);
     ui->location_lineEdit->setText(QDir::currentPath());
-    setWindowIcon(QIcon("icons/document-save-as.png"));
+
+    //set the icon of save as
+    char *PROGRAM_DIR=get_absolute_speckle_tool_path();
+    setWindowIcon(QIcon( QString(PROGRAM_DIR)+"../share/speckletool/icons/document-save-as.png"));
 }
 
 SaveImageSequenceInterface::~SaveImageSequenceInterface()
 {
     delete ui;
+    ui=NULL;
 }
 
 void SaveImageSequenceInterface::on_location_pushButton_clicked()
 {
-    aux = QFileDialog::getExistingDirectory(this,
-                                                tr("Select Folder"),
-                                                QDir::currentPath());
+    aux = QFileDialog::getExistingDirectory(this, tr("Select Folder"), QDir::currentPath());
     ui->location_lineEdit->setText(aux);
 }
 
